==> ldapjdk_5.0.0+dfsg1.orig.tar.xz: ldap-sdk-5.0.0/java-sdk/ietfldap/org/ietf/ldap/client/opers/JDAPUnbindRequest.java <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package org.ietf.ldap.client.opers;

import java.util.*;
import org.ietf.ldap.client.*;
import org.ietf.ldap.ber.stream.*;
import java.io.*;
import java.net.*;

/**
 * This class implements the unbind request and is a protocol operation.
 * A protocol operation is embedded within JDAPMessage which is sent
 * between client and server. This object is sent to the ldap server.
 * <pre>
 * UnbindRequest ::= [APPLICATION 2] NULL
 * </pre>
 *
 * @version 1.0
 */
public class JDAPUnbindRequest implements JDAPProtocolOp {
    /**
     * Constructs bind request.
     */
    public JDAPUnbindRequest() {
    }

    /**
     * Retrieves the protocol operation type.
     * @return operation type
     */
    public int getType() {
        return JDAPProtocolOp.UNBIND_REQUEST;
    }

    /**
     * Gets the ber representation of the unbind rquest.
     * @return ber representation
     */
    public BERElement getBERElement() {
        /*
         * [*] umich-ldap-v3.3:
         *     0x42 0x00
         * [*] umich-ldap-v3.0:
         */
        BERNull n = new BERNull();
        BERTag element = new BERTag(BERTag.APPLICATION|2, n, true);
        return element;
    }

    /**
     * Retrieves the string representation of unbind operation.
     * @return string representation
     */
    public String toString() {
        return "UnbindRequest {}";
    }
}

==> ldapjdk_5.3.0+dfsg1.orig.tar.xz: ldap-sdk-5.3.0/java-sdk/ietfldap/org/ietf/ldap/client/opers/JDAPUnbindRequest.java <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package org.ietf.ldap.client.opers;

import org.ietf.ldap.ber.stream.BERElement;
import org.ietf.ldap.ber.stream.BERNull;
import org.ietf.ldap.ber.stream.BERTag;

/**
 * This class implements the unbind request and is a protocol operation.
 * A protocol operation is embedded within JDAPMessage which is sent
 * between client and server. This object is sent to the ldap server.
 * <pre>
 * UnbindRequest ::= [APPLICATION 2] NULL
 * </pre>
 *
 * @version 1.0
 */
public class JDAPUnbindRequest implements JDAPProtocolOp {
    /**
     * Constructs bind request.
     */
    public JDAPUnbindRequest() {
    }

    /**
     * Retrieves the protocol operation type.
     * @return operation type
     */
    public int getType() {
        return JDAPProtocolOp.UNBIND_REQUEST;
    }

    /**
     * Gets the ber representation of the unbind rquest.
     * @return ber representation
     */
    public BERElement getBERElement() {
        /*
         * [*] umich-ldap-v3.3:
         *     0x42 0x00
         * [*] umich-ldap-v3.0:
         */
        BERNull n = new BERNull();
        BERTag element = new BERTag(BERTag.APPLICATION|2, n, true);
        return element;
    }

    /**
     * Retrieves the string representation of unbind operation.
     * @return string representation
     */
    public String toString() {
        return "UnbindRequest {}";
    }
}
